# **Vehicle activity analysis** 🚛

A light-weight module for analysis of GPS activity

## **Waste Labs use cases** ♻️

* 📈 **KPI monitoring**: clusters helps us to determine how much time vehicle spent on-site, how much it travelled
* 📍 **Pick up locations verification**: helps to estimate if provided customer locations is groud truth

---

## **Navigation**

* [GPS activity library modules](docs/gps_activity/README.md) 🚚 🚛 📍
* [GPS activity extraction architectire](docs/gps_activity/extraction/README.md) ⚙️
* [GPS activity extraction available models](docs/gps_activity/extraction/available_models/VHFDBSCAN/README.md) 🚀
* [Performance dataset collection](docs/performance_dataset_collection/README.md) 🎯
